@@ -17,6 +17,9 @@
 
 #include "playlistcollection.h"
 
+#include <algorithm>
+#include <utility>
+
 #include <kio_version.h>
 #include <kwidgetsaddons_version.h>
 #include <kiconloader.h>
@@ -28,8 +31,6 @@
 #include <KSharedConfig>
 #include <kfileitem.h>
 
-#include <config-juk.h>
-
 #include <QAction>
 #include <QIcon>
 #include <QMutableListIterator>
@@ -46,6 +47,7 @@
 #include "actioncollection.h"
 #include "advancedsearchdialog.h"
 #include "collectionlist.h"
+#include "config-juk.h"
 #include "coverinfo.h"
 #include "directorylist.h"
 #include "folderplaylist.h"
@@ -64,6 +66,9 @@
 // static methods
 ////////////////////////////////////////////////////////////////////////////////
 
+using namespace Qt::Literals::StringLiterals;
+using std::as_const;
+
 PlaylistCollection *PlaylistCollection::m_instance = nullptr;
 
 // Returns all folders in input list with their canonical path, if available, or
@@ -72,7 +77,7 @@ static QStringList canonicalizeFolderPaths(const QStringList &folders)
 {
     QStringList result;
 
-    foreach(const QString &folder, folders) {
+    for(const QString &folder : folders) {
         QString canonicalFolder = QDir(folder).canonicalPath();
         result << (!canonicalFolder.isEmpty() ? canonicalFolder : folder);
     }
@@ -255,13 +260,12 @@ void PlaylistCollection::showMore(const QString &artist, const QString &album)
 void PlaylistCollection::removeTrack(const QString &playlist, const QStringList &files)
 {
     Playlist *p = playlistByName(playlist);
-    PlaylistItemList itemList;
     if(!p)
         return;
 
-    QStringList::ConstIterator it;
-    for(it = files.begin(); it != files.end(); ++it) {
-        CollectionListItem *item = CollectionList::instance()->lookup(*it);
+    PlaylistItemList itemList;
+    for(const QString &file : files) {
+        CollectionListItem *item = CollectionList::instance()->lookup(file);
 
         if(item) {
             PlaylistItem *playlistItem = item->itemForPlaylist(p);
@@ -326,20 +330,6 @@ QPixmap PlaylistCollection::trackCover(const QString &file, const QString &size)
 
 void PlaylistCollection::open(const QStringList &l)
 {
-    const auto questionFunc =
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5,100,0)
-        &KMessageBox::questionTwoActions;
-#else
-        &KMessageBox::questionYesNo;
-#endif
-
-    const auto secondaryResponse =
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5,100,0)
-        KMessageBox::SecondaryAction;
-#else
-        KMessageBox::No;
-#endif
-
     QStringList files = l;
 
     if(files.isEmpty())
@@ -348,20 +338,18 @@ void PlaylistCollection::open(const QStringList &l)
     if(files.isEmpty())
         return;
 
-    bool justPlaylists = true;
-
-    for(QStringList::ConstIterator it = files.constBegin(); it != files.constEnd() && justPlaylists; ++it)
-        justPlaylists = !MediaFiles::isPlaylistFile(*it);
+    bool justPlaylists = std::all_of(files.cbegin(), files.cend(),
+            [](const auto &file) { return MediaFiles::isPlaylistFile(file); });
 
     if(visiblePlaylist() == CollectionList::instance() || justPlaylists ||
-       questionFunc(
+       KMessageBox::questionTwoActions(
            JuK::JuKInstance(),
            i18n("Do you want to add these items to the current list or to the collection list?"),
            QString(),
            KGuiItem(i18nc("current playlist", "Current")),
            KGuiItem(i18n("Collection")),
            QString(),
-           KMessageBox::Notify) == secondaryResponse)
+           KMessageBox::Notify) == KMessageBox::SecondaryAction)
     {
         CollectionList::instance()->addFiles(files);
     }
@@ -384,36 +372,38 @@ void PlaylistCollection::addFolder()
 {
     DirectoryList l(m_folderList, m_excludedFolderList, m_importPlaylists, JuK::JuKInstance());
 
-    if(l.exec() == QDialog::Accepted) {
-        m_dirLister.blockSignals(true);
-        DirectoryList::Result result = l.dialogResult();
-
-        const bool reload = m_importPlaylists != result.addPlaylists;
-
-        m_importPlaylists = result.addPlaylists;
-        m_excludedFolderList = canonicalizeFolderPaths(result.excludedDirs);
-
-        foreach(const QString &dir, result.addedDirs) {
-            m_dirLister.openUrl(QUrl::fromLocalFile(dir), KDirLister::Keep);
-            m_folderList.append(dir);
-        }
-
-        foreach(const QString &dir, result.removedDirs) {
-            m_dirLister.stop(QUrl::fromLocalFile(dir));
-            m_folderList.removeAll(dir);
-        }
-
-        if(reload) {
-            open(m_folderList);
-        }
-        else if(!result.addedDirs.isEmpty()) {
-            open(result.addedDirs);
-        }
-
-        saveConfig();
-
-        m_dirLister.blockSignals(false);
+    if(l.exec() != QDialog::Accepted) {
+        return;
     }
+
+    m_dirLister.blockSignals(true);
+    const DirectoryList::Result result = l.dialogResult();
+
+    const bool reload = m_importPlaylists != result.addPlaylists;
+
+    m_importPlaylists = result.addPlaylists;
+    m_excludedFolderList = canonicalizeFolderPaths(result.excludedDirs);
+
+    for(const QString &dir : result.addedDirs) {
+        m_dirLister.openUrl(QUrl::fromLocalFile(dir), KDirLister::Keep);
+        m_folderList.append(dir);
+    }
+
+    for(const QString &dir : result.removedDirs) {
+        m_dirLister.stop(QUrl::fromLocalFile(dir));
+        m_folderList.removeAll(dir);
+    }
+
+    if(reload) {
+        open(m_folderList);
+    }
+    else if(!result.addedDirs.isEmpty()) {
+        open(result.addedDirs);
+    }
+
+    saveConfig();
+
+    m_dirLister.blockSignals(false);
 }
 
 void PlaylistCollection::rename()
@@ -497,34 +487,6 @@ void PlaylistCollection::renameItems()
     visiblePlaylist()->slotRenameFile();
 }
 
-void PlaylistCollection::addLocalCover()
-{
-    visiblePlaylist()->slotAddCover(true /* from file */);
-    playlistItemsChanged();
-}
-
-void PlaylistCollection::addInternetCover()
-{
-    visiblePlaylist()->slotAddCover(false /* not from file */);
-    playlistItemsChanged();
-}
-
-void PlaylistCollection::removeCovers()
-{
-    visiblePlaylist()->slotRemoveCover();
-    playlistItemsChanged();
-}
-
-void PlaylistCollection::viewCovers()
-{
-    visiblePlaylist()->slotViewCover();
-}
-
-void PlaylistCollection::showCoverManager()
-{
-    visiblePlaylist()->slotShowCoverManager();
-}
-
 PlaylistItemList PlaylistCollection::selectedItems()
 {
     return visiblePlaylist()->selectedItems();
@@ -799,7 +761,7 @@ QString PlaylistCollection::uniquePlaylistName(const QString &suggest) const
         return suggest;
 
     QString base = suggest;
-    base.remove(QRegExp("\\s\\([0-9]+\\)$"));
+    base.remove(QRegularExpression("\\s\\([0-9]+\\)$"));
 
     int count = 1;
     QString s = QString("%1 (%2)").arg(base).arg(count);
@@ -838,7 +800,7 @@ void PlaylistCollection::dirChanged(const QString &path)
     if(canonicalPath.isEmpty())
         return;
 
-    foreach(const QString &excludedFolder, m_excludedFolderList) {
+    for(const QString &excludedFolder : as_const(m_excludedFolderList)) {
         if(canonicalPath.startsWith(excludedFolder))
             return;
     }
@@ -854,7 +816,7 @@ Playlist *PlaylistCollection::playlistByName(const QString &name) const
             return p;
     }
 
-    return 0;
+    return nullptr;
 }
 
 void PlaylistCollection::newItems(const KFileItemList &list) const
@@ -862,25 +824,21 @@ void PlaylistCollection::newItems(const KFileItemList &list) const
     // Make fast-path for the normal case
     if(m_excludedFolderList.isEmpty()) {
         CollectionList::instance()->slotNewItems(list);
-        return;
     }
+    else {
+        KFileItemList filteredList(list);
+        erase_if(filteredList, [this](const KFileItem &fileItem) {
+                const auto prefix = fileItem.url().path();
+                for(const auto &folder : m_excludedFolderList) {
+                    if(prefix.startsWith(folder)) {
+                        return true;
+                    }
+                }
+                return false;
+                });
 
-    // Slow case: Directories to exclude from consideration
-
-    KFileItemList filteredList(list);
-
-    foreach(const QString &excludedFolder, m_excludedFolderList) {
-        QMutableListIterator<KFileItem> filteredListIterator(filteredList);
-
-        while(filteredListIterator.hasNext()) {
-            const KFileItem fileItem = filteredListIterator.next();
-
-            if(fileItem.url().path().startsWith(excludedFolder))
-                filteredListIterator.remove();
-        }
+        CollectionList::instance()->slotNewItems(filteredList);
     }
-
-    CollectionList::instance()->slotNewItems(filteredList);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -889,21 +847,21 @@ void PlaylistCollection::newItems(const KFileItemList &list) const
 
 void PlaylistCollection::readConfig()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "Playlists");
+    KConfigGroup config(KSharedConfig::openConfig(), u"Playlists"_s);
 
     m_importPlaylists    = config.readEntry("ImportPlaylists", true);
     m_folderList         = config.readEntry("DirectoryList", QStringList());
     m_excludedFolderList = canonicalizeFolderPaths(
             config.readEntry("ExcludeDirectoryList", QStringList()));
 
-    for(const auto &folder : qAsConst(m_folderList)) {
+    for(const auto &folder : std::as_const(m_folderList)) {
         m_dirLister.openUrl(QUrl::fromUserInput(folder), KDirLister::Keep);
     }
 }
 
 void PlaylistCollection::saveConfig()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "Playlists");
+    KConfigGroup config(KSharedConfig::openConfig(), u"Playlists"_s);
     config.writeEntry("ImportPlaylists", m_importPlaylists);
     config.writeEntry("showUpcoming", ActionCollection::action("showUpcoming")->isChecked());
     config.writePathEntry("DirectoryList", m_folderList);
@@ -935,15 +893,15 @@ PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
     menu->addAction(createAction(i18n("&Empty Playlist..."),
                 qOverload<>(&PlaylistCollection::createPlaylist),
                 "newPlaylist", "window-new",
-                QKeySequence(Qt::CTRL + Qt::Key_N)));
+                QKeySequence(Qt::CTRL | Qt::Key_N)));
     menu->addAction(createAction(i18n("&Search Playlist..."),
                 &PlaylistCollection::createSearchPlaylist,
                 "newSearchPlaylist", "edit-find",
-                QKeySequence(Qt::CTRL + Qt::Key_F)));
+                QKeySequence(Qt::CTRL | Qt::Key_F)));
     menu->addAction(createAction(i18n("Playlist From &Folder..."),
                 &PlaylistCollection::createFolderPlaylist,
                 "newDirectoryPlaylist", "document-open",
-                QKeySequence(Qt::CTRL + Qt::Key_D)));
+                QKeySequence(Qt::CTRL | Qt::Key_D)));
 
     // Guess tag info menu
 
@@ -956,16 +914,16 @@ PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
     menu->addAction(createAction(i18n("From &File Name"),
                 &PlaylistCollection::guessTagFromFile,
                 "guessTagFile", "document-import",
-                QKeySequence(Qt::CTRL + Qt::Key_G)));
+                QKeySequence(Qt::CTRL | Qt::Key_G)));
     menu->addAction(createAction(i18n("From &Internet"),
                 &PlaylistCollection::guessTagFromInternet,
                 "guessTagInternet", "network-server",
-                QKeySequence(Qt::CTRL + Qt::Key_I)));
+                QKeySequence(Qt::CTRL | Qt::Key_I)));
 #else
     createAction(i18n("Guess Tag Information From &File Name"),
                 &PlaylistCollection::guessTagFromFile,
                 "guessTag", "document-import",
-                QKeySequence(Qt::CTRL + Qt::Key_G));
+                QKeySequence(Qt::CTRL | Qt::Key_G));
 #endif
 
 
@@ -1000,24 +958,7 @@ PlaylistCollection::ActionHandler::ActionHandler(PlaylistCollection *collection)
             "openItemDir", "stock_folder");
     createAction(i18n("&Rename File"), &PlaylistCollection::renameItems,
             "renameFile", "document-save-as",
-            QKeySequence(Qt::CTRL + Qt::Key_R));
-
-    menu = new KActionMenu(i18n("Cover Manager"), actionCollection);
-    actionCollection->addAction("coverManager", menu);
-    menu->setIcon("image-x-generic"_icon);
-    menu->addAction(createAction(i18n("&View Cover"),
-        &PlaylistCollection::viewCovers, "viewCover", "document-preview"));
-    menu->addAction(createAction(i18n("Get Cover From &File..."),
-        &PlaylistCollection::addLocalCover, "addCover", "document-import",
-        QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F)));
-    menu->addAction(createAction(i18n("Get Cover From &Internet..."),
-        &PlaylistCollection::addInternetCover,
-        "webImageCover", "network-server",
-        QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_G)));
-    menu->addAction(createAction(i18n("&Delete Cover"),
-        &PlaylistCollection::removeCovers, "removeCover", "edit-delete"));
-    menu->addAction(createAction(i18n("Show Cover &Manager"),
-        &PlaylistCollection::showCoverManager, "showCoverManager"));
+            QKeySequence(Qt::CTRL | Qt::Key_R));
 
     auto upcomingAction = new KToggleAction(
             "go-jump-today"_icon, i18n("Show &Play Queue"), actionCollection);
